Enum dicom_object::file::ReadPreamble
source · pub enum ReadPreamble {
Auto,
Never,
Always,
}Expand description
An enumerate of supported options for whether to read the 128-byte DICOM file preamble.
Variants
Auto
Read the preamble only when opening a file by path, and do not read the preamble when reading from a byte source.
Never
Never read the preamble, thus assuming that the original source does not have it.
Always
Always read the preamble first, thus assuming that the original source always has it.