Module dicom_object::ops
source · Expand description
Baseline attribute operation implementations.
See the dicom_core::ops module
for more information.
Enums
- An error which may occur when applying an attribute operation to an object.
Type Aliases
- Result type for when applying attribute operations to an object.