Struct dicom_object::pixeldata::InMemoryPixelData
source · pub struct InMemoryPixelData<C, P> { /* private fields */ }👎Deprecated since 0.5.0: This is a stub, use the
dicom-pixeldata crate insteadExpand description
A DICOM slice that is completely stored in memory, which may be owned by this and owned by a local vector. Pixels are stored in row-major order with no padding.
Implementations
sourceimpl<C, P> InMemoryPixelData<C, P>
impl<C, P> InMemoryPixelData<C, P>
sourcepub fn into_raw_data(self) -> C
👎Deprecated since 0.5.0: This is a stub, use the dicom-pixeldata crate instead
pub fn into_raw_data(self) -> C
dicom-pixeldata crate insteadFetch the internal data container, destroying the pixel data structure in the process.
sourcepub fn raw_data(&self) -> &C
👎Deprecated since 0.5.0: This is a stub, use the dicom-pixeldata crate instead
pub fn raw_data(&self) -> &C
dicom-pixeldata crate insteadObtain a reference to the internal data container.
sourcepub fn raw_data_mut(&mut self) -> &mut C
👎Deprecated since 0.5.0: This is a stub, use the dicom-pixeldata crate instead
pub fn raw_data_mut(&mut self) -> &mut C
dicom-pixeldata crate insteadObtain a reference to the internal data container.