Struct dicom_object::Tag
source · pub struct Tag(pub u16, pub u16);Expand description
The data type for DICOM data element tags.
Tags are composed by a (group, element) pair of 16-bit unsigned integers.
Aside from writing a struct expression,
a Tag may also be built by converting a (u16, u16) or a [u16; 2].
In its text form,
DICOM tags are printed by Display in the form (GGGG,EEEE),
where the group and element parts are in uppercase hexadecimal.
Moreover, its FromStr implementation
support converting strings in the following text formats into DICOM tags:
(GGGG,EEEE)GGGG,EEEEGGGGEEEE
Example
let tag: Tag = "(0010,1005)".parse()?;
assert_eq!(tag, Tag(0x0010, 0x1005));Tuple Fields
0: u161: u16Implementations