Enum dicom_object::meta::Error

source ·
#[non_exhaustive]
pub enum Error {
    ReadMagicCode {
        backtrace: Backtrace,
        source: Error,
    },
    ReadValueData {
        backtrace: Backtrace,
        source: Error,
    },
    AllocationSize {
        backtrace: Backtrace,
        source: TryReserveError,
    },
    DecodeText {
        name: &'static str,
        source: DecodeTextError,
    },
    NotDicom {
        backtrace: Backtrace,
    },
    DecodeElement {
        source: Error,
    },
    UnexpectedTag {
        tag: Tag,
        backtrace: Backtrace,
    },
    MissingElement {
        alias: &'static str,
        backtrace: Backtrace,
    },
    UnexpectedDataValueLength {
        tag: Tag,
        length: Length,
        backtrace: Backtrace,
    },
    UndefinedValueLength {
        tag: Tag,
        backtrace: Backtrace,
    },
    WriteSet {
        source: Error,
    },
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ReadMagicCode

Fields

backtrace: Backtrace
source: Error

The file meta group parser could not read the magic code DICM from its source.



ReadValueData

Fields

backtrace: Backtrace
source: Error

The file meta group parser could not fetch the value of a data element from its source.



AllocationSize

Fields

backtrace: Backtrace

The parser could not allocate memory for the given length of a data element.



DecodeText

Fields

name: &'static str

The file meta group parser could not decode the text in one of its data elements.



NotDicom

Fields

backtrace: Backtrace

Invalid DICOM data, detected by checking the DICM code.



DecodeElement

Fields

source: Error

An issue occurred while decoding the next data element in the file meta data set.



UnexpectedTag

Fields

tag: Tag
backtrace: Backtrace

A data element with an unexpected tag was retrieved: the parser was expecting another tag first, or at least one that is part of the the file meta group.



MissingElement

Fields

alias: &'static str
backtrace: Backtrace

A required file meta data element is missing.



UnexpectedDataValueLength

Fields

tag: Tag
length: Length
backtrace: Backtrace

The value length of a data elements in the file meta group was unexpected.



UndefinedValueLength

Fields

tag: Tag
backtrace: Backtrace

The value length of a data element is undefined, but knowing the length is required in its context.



WriteSet

Fields

source: Error

The file meta group data set could not be written.