pub struct FileMetaTable {
    pub information_group_length: u32,
    pub information_version: [u8; 2],
    pub media_storage_sop_class_uid: String,
    pub media_storage_sop_instance_uid: String,
    pub transfer_syntax: String,
    pub implementation_class_uid: String,
    pub implementation_version_name: Option<String>,
    pub source_application_entity_title: Option<String>,
    pub sending_application_entity_title: Option<String>,
    pub receiving_application_entity_title: Option<String>,
    pub private_information_creator_uid: Option<String>,
    pub private_information: Option<Vec<u8>>,
}
DICOM File Meta Information Table.

This data type contains the relevant parts of the file meta information table, as specified in part 6, chapter 7 of the standard.

Creating a new file meta table from scratch is more easily done using a FileMetaTableBuilder. When modifying the struct’s public fields, it is possible to update the information group length through method update_information_group_length.

Fields

information_group_length: u32

File Meta Information Group Length

information_version: [u8; 2]

File Meta Information Version

media_storage_sop_class_uid: String

Media Storage SOP Class UID

media_storage_sop_instance_uid: String

Media Storage SOP Instance UID

transfer_syntax: String

Transfer Syntax UID

implementation_class_uid: String

Implementation Class UID

implementation_version_name: Option<String>

Implementation Version Name

source_application_entity_title: Option<String>

Source Application Entity Title

sending_application_entity_title: Option<String>

Sending Application Entity Title

receiving_application_entity_title: Option<String>

Receiving Application Entity Title

private_information_creator_uid: Option<String>

Private Information Creator UID

private_information: Option<Vec<u8>>

Private Information

Implementations

Construct a file meta group table by parsing a DICOM data set from a reader.

Getter for the transfer syntax UID, with trailing characters already excluded.

Getter for the media storage SOP instance UID, with trailing characters already excluded.

Getter for the media storage SOP class UID, with trailing characters already excluded.

Getter for the implementation class UID, with trailing characters already excluded.

Getter for the private information creator UID, with trailing characters already excluded.

Set the file meta table’s transfer syntax according to the given transfer syntax descriptor.

Extra padding to even length is trimmed.

Note that the field information_group_length is not updated to consider the length of the new transfer syntax. Should you wish to keep the field up to date, call update_information_group_length afterwards.

Calculate the expected file meta group length according to the file meta attributes currently set, and assign it to the field information_group_length.

Create an iterator over the defined data elements of the file meta group, consuming the file meta table.

See to_element_iter for a version which copies the element from the table.

Create an iterator of data elements copied from the file meta group.

See into_element_iter for a version which consumes the table.